@@ -538,14 +538,18 @@ class KeyProtect(BaseClient):
 
         return resp.json().get("resources", [])
 
-    def get_key(self, key_id):
-        resp = self.session.get("%s/api/v2/keys/%s" % (self.endpoint_url, key_id))
+    def get_key(self, key_id_or_alias):
+        resp = self.session.get(
+            "%s/api/v2/keys/%s" % (self.endpoint_url, key_id_or_alias)
+        )
 
         self._validate_resp(resp)
 
         return resp.json().get("resources")[0]
 
-    def create_key(self, name, payload=None, raw_payload=None, root=False):
+    def create_key(
+        self, name, payload=None, raw_payload=None, root=False, alias_list=None
+    ):
 
         data = {
             "metadata": {
@@ -567,6 +571,13 @@ class KeyProtect(BaseClient):
         elif payload is not None:
             data["resources"][0]["payload"] = base64.b64encode(payload).decode("utf-8")
 
+        # creates a new key with alias name. A key can have a maximum of 5 alias names
+        if alias_list:
+            if len(alias_list) > 5:
+                raise ValueError("A key can not have more than 5 alias names")
+            else:
+                data["resources"][0]["aliases"] = alias_list
+
         resp = self.session.post("%s/api/v2/keys" % self.endpoint_url, json=data)
         self._validate_resp(resp)
         return resp.json().get("resources")[0]
@@ -615,6 +626,20 @@ class KeyProtect(BaseClient):
 
         return self._action(key_id, "rotate", data)
 
+    def restore_key(self, key_id: str):
+        """
+        Restore a key.
+
+        The RestoreKey method reverts a key's status from `Destroyed` to `Active`.
+        This method cannot be used to restore a key that has been purged.
+
+        API Docs: https://cloud.ibm.com/apidocs/key-protect#restorekey
+        """
+        resp = self.session.post(
+            "%s/api/v2/keys/%s/restore" % (self.endpoint_url, key_id)
+        )
+        self._validate_resp(resp)
+
     def disable_key(self, key_id: str):
         """
         Disable a key.
@@ -842,6 +867,29 @@ class KeyProtect(BaseClient):
         self._validate_resp(resp)
         return resp.json()
 
+    def initiate_dual_auth_delete(self, key_id: str):
+        """
+        Authorize deletion for a key with a dual authorization policy
+
+        API Docs: https://cloud.ibm.com/apidocs/key-protect#setkeyfordeletion
+        """
+        resp = self.session.post(
+            "%s/api/v2/keys/%s/actions/setKeyForDeletion" % (self.endpoint_url, key_id)
+        )
+        self._validate_resp(resp)
+
+    def cancel_dual_auth_delete(self, key_id: str):
+        """
+        Remove an authorization for a key with a dual authorization policy
+
+        API Docs: https://cloud.ibm.com/apidocs/key-protect#unsetkeyfordeletion
+        """
+        resp = self.session.post(
+            "%s/api/v2/keys/%s/actions/unsetKeyForDeletion"
+            % (self.endpoint_url, key_id)
+        )
+        self._validate_resp(resp)
+
     def set_instance_dual_auth_policy(self, dual_auth_enable: bool):
         """
         Updates the dual auth delete policy for the instance by passing the enable detail
@@ -896,16 +944,88 @@ class KeyProtect(BaseClient):
         ]
         return self._set_policy(resources_list)
 
+    def set_instance_key_create_import_access_policy(
+        self,
+        key_create_import_access_enable: bool,
+        create_root_key: bool,
+        create_standard_key: bool,
+        import_root_key: bool,
+        import_standard_key: bool,
+        enforce_token: bool,
+    ):
+        """
+        Updates the key create import access policy details associated with an instance.
+
+        'key_create_import_access_enable' is boolean type, the instance policy is enabled if it's set to true
+
+        API Docs: https://cloud.ibm.com/apidocs/key-protect#putinstancepolicy
+        """
+        resources_list = [
+            {
+                "policy_type": "keyCreateImportAccess",
+                "policy_data": {
+                    "enabled": key_create_import_access_enable,
+                    "attributes": {
+                        "create_root_key": create_root_key,
+                        "create_standard_key": create_standard_key,
+                        "import_root_key": import_root_key,
+                        "import_standard_key": import_standard_key,
+                        "enforce_token": enforce_token,
+                    },
+                },
+            }
+        ]
+        return self._set_policy(resources_list)
+
+    def set_instance_metrics_policy(self, metrics_enable: bool):
+        """
+        Updates the metrics policy details associated with an instance
+
+        API Docs: https://cloud.ibm.com/apidocs/key-protect#putinstancepolicy
+        """
+        resources_list = [
+            {
+                "policy_type": "metrics",
+                "policy_data": {"enabled": metrics_enable},
+            }
+        ]
+        return self._set_policy(resources_list)
+
     def get_instance_policies(self):
         """
         Retrieves a list of policies that are associated with a specified service instance
 
         https://cloud.ibm.com/apidocs/key-protect#getinstancepolicy
         """
-        resp = self.session.get("%s/api/v2/instance/policies" % (self.endpoint_url))
+        resp = self.session.get("%s/api/v2/instance/policies" % self.endpoint_url)
         self._validate_resp(resp)
         return resp.json()
 
+    def set_key_ring(self, key_id: str, key_ring_id: str, new_key_ring_id: str):
+        """
+        Transfers a key associated with one key ring to another key ring
+
+        https://cloud.ibm.com/apidocs/key-protect#patchkey
+        """
+        resp = self.session.patch(
+            "%s/api/v2/keys/%s" % (self.endpoint_url, key_id),
+            json={"keyRingID": new_key_ring_id},
+            headers={"X-Kms-Key-Ring": key_ring_id},
+        )
+        self._validate_resp(resp)
+
+    def purge_key(self, key_id: str):
+        """
+        Purge key method shreds all the metadata and registrations associated with a key that has been
+        deleted. The purge operation is allowed to be performed on a key from 4 hours after its deletion
+
+        https://cloud.ibm.com/apidocs/key-protect#purgekey
+        """
+        resp = self.session.delete(
+            "%s/api/v2/keys/%s/purge" % (self.endpoint_url, key_id)
+        )
+        self._validate_resp(resp)
+
     # deprecated methods
     keys = list_keys
     get = get_key
